<?php
/**
 * Themaga Class: The main class of theme
 *
 * @author   ThemeCountry
 * @since    1.0.0
 * @package  themaga
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Themaga' ) ) :

	/**
	 * The main Themaga class to init & setup theme
	 *
	 * @since  1.0.0
	 * @version  1.0
	 */
	class Themaga
	{

		function __construct() {

			add_action( 'after_setup_theme',          array( $this, 'setup' ) );
			add_action( 'widgets_init',               array( $this, 'widgets_init' ) );
			add_action( 'wp_enqueue_scripts',         array( $this, 'scripts' ),       10 );
			//add_action( 'wp_enqueue_scripts',         array( $this, 'child_scripts' ), 30 );


			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

			// After WooCommerce.
			add_filter( 'body_class',                 array( $this, 'body_classes' ) );
			//add_filter( 'wp_page_menu_args',          array( $this, 'page_menu_args' ) );


		}

		/**
		 * Sets up theme defaults and registers support for various WordPress features.
		 *
		 * Note that this function is hooked into the after_setup_theme hook, which
		 * runs before the init hook. The init hook is too late for some features, such
		 * as indicating support for post thumbnails.
		 *
		 * @since 1.0
		 */
		public function setup() {

			/*
			 * Make theme available for translation.
			 * Translations can be filed in the /languages/ directory.
			 * If you're building a theme based on themaga, use a find and replace
			 * to change 'themaga' to the name of your theme in all the template files.
			 */

			// Loads wp-content/themes/base/languages/it_IT.mo.
			load_theme_textdomain( 'themaga', get_template_directory() . '/languages' );

			// Add default posts and comments RSS feed links to head.
			add_theme_support( 'automatic-feed-links' );

			/*
			 * Let WordPress manage the document title.
			 * By adding theme support, we declare that this theme does not use a
			 * hard-coded <title> tag in the document head, and expect WordPress to
			 * provide it for us.
			 */
			add_theme_support( 'title-tag' );

			/*
			 * Enable support for Post Thumbnails on posts and pages.
			 *
			 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
			 */

			add_theme_support( 'post-thumbnails' );

			/**
			 * Enable support for site logo
			 */
			// Set up the WordPress core custom logo feature.
			add_theme_support( 'custom-logo', apply_filters( 'themaga_custom_logo_args', array(
					'height'		=> 90,
					'width'			=> 300,
					'flex-width'	=> true,
			) ) );


			// This theme uses wp_nav_menu() in two locations.
			register_nav_menus( array(
				'primary'   => __( 'Primary Menu', 'themaga' ),
			) );

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			) );


			/**
			 *  Add support for the Site Logo plugin and the site logo functionality in JetPack
			 *  https://github.com/automattic/site-logo
			 *  http://jetpack.me/
			 */
			add_theme_support( 'site-logo', array( 'size' => 'full' ) );

			// Set up the WordPress core custom background feature.
			add_theme_support( 'custom-background', apply_filters( 'themaga_custom_background_args', array(
					'default-color'		=> 'ffffff',
					'default-image'		=> '',
			) ) );

			add_theme_support( 'custom-header', apply_filters( 'themaga_custom_header_args', array(
				'header-text'			=> false,
				'width'					=> 1600,
				'height'				=> 640,
				'flex-height'			=> true,
			) ) );

			// Add thirt party plugin
			$this->_addons_support();

			// Add theme support for selective refresh for widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );
		}

		/**
		 * Adds theme support pro version
		 *
		 * @since 1.0
		 * @return void
		 */
		private function _addons_support() {

			// Add theme support for Themaga Pro plugin.
			add_theme_support( 'themaga-pro' );


		}

		/**
		 * Register widget area.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
		 * @since 1.0
		 */
		public function widgets_init() {

			$sidebar_args['sidebar'] = array(
				'name'          => __( 'Sidebar', 'themaga' ),
				'id'            => 'sidebar-1',
				'description'   => ''
			);

			$sidebar_args['adsfeatured'] = array(
				'name'          => __( 'Ads under Featured', 'themaga' ),
				'id'            => 'adsfeatured-1',
				'description'   => ''
			);

			$sidebar_args['adsfooter'] = array(
				'name'          => __( 'Ads Footer', 'themaga' ),
				'id'            => 'adsfooter-1',
				'description'   => ''
			);

			$rows    = intval( apply_filters( 'themaga_footer_widget_rows', 1 ) );
			$regions = intval( apply_filters( 'themaga_footer_widget_columns', 4 ) );

			for ( $row = 1; $row <= $rows; $row++ ) {
				for ( $region = 1; $region <= $regions; $region++ ) {
					$footer_n = $region + $regions * ( $row - 1 ); // Defines footer sidebar ID.
					$footer   = sprintf( 'footer_%d', $footer_n );

					if ( 1 == $rows ) {
						$footer_region_name = sprintf( __( 'Footer Column %1$d', 'themaga' ), $region );
						$footer_region_description = sprintf( __( 'Widgets added here will appear in column %1$d of the footer.', 'themaga' ), $region );
					} else {
						$footer_region_name = sprintf( __( 'Footer Row %1$d - Column %2$d', 'themaga' ), $row, $region );
						$footer_region_description = sprintf( __( 'Widgets added here will appear in column %1$d of footer row %2$d.', 'themaga' ), $region, $row );
					}

					$sidebar_args[ $footer ] = array(
						'name'        => $footer_region_name,
						'id'          => sprintf( 'footer-%d', $footer_n ),
						'description' => $footer_region_description,
					);
				}
			}

			foreach ( $sidebar_args as $sidebar => $args ) {
				$widget_tags = array(
					'before_widget' => '<div id="%1$s" class="widget %2$s">',
					'after_widget'  => '</div>',
					'before_title'  => '<div class="widget-title"><span>',
					'after_title'   => '</span></div>',
				);

				/**
				 * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See the list below.
				 *
				 * 'themaga_header_widget_tags'
				 * 'themaga_sidebar_widget_tags'
				 *
				 * 'themaga_footer_1_widget_tags'
				 * 'themaga_footer_2_widget_tags'
				 * 'themaga_footer_3_widget_tags'
				 * 'themaga_footer_4_widget_tags'
				 */
				$filter_hook = sprintf( 'themaga_%s_widget_tags', $sidebar );
				$widget_tags = apply_filters( $filter_hook, $widget_tags );

				if ( is_array( $widget_tags ) ) {
					register_sidebar( $args + $widget_tags );
				}
			}
		}

		public function enqueue_scripts() {

			global $wp_query, $themaga_version;

			wp_enqueue_style( 'themaga-admin', get_template_directory_uri() . '/assets/css/admin/admin.css', '', $themaga_version );
		}



		/**
		 * Enqueue scripts and styles.
		 *
		 * @since  1.0
		 */
		public function scripts() {

			global $wp_query, $themaga_version;

			/**
			 * Styles
			 */

			wp_enqueue_style( 'themaga-style', get_template_directory_uri() . '/style.css', '', $themaga_version );

			wp_enqueue_style( 'themaga-icons', get_template_directory_uri() . '/assets/css/base/icons.css', '', $themaga_version );

			/**
			 * Fonts
			 */
			$google_fonts = apply_filters( 'themaga_google_font_families', array(
				'Montserrat' 	=> 'Montserrat:300,400,500,700&subset=latin,latin-ext'
			) );

			if ( $google_fonts ) {

				$query_args = array(
					'family' => implode( '|', $google_fonts )
				);

				$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );


				wp_enqueue_style( 'themaga-fonts', $fonts_url, array(), null );

			}

			/**
			 * Scripts
			 */
			wp_enqueue_script( 'themaga-navigation', get_template_directory_uri() . '/js/navigation.js', array(), $themaga_version, true );


			wp_enqueue_script( 'themaga-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), $themaga_version, true );
			wp_enqueue_script( 'themaga-script', get_template_directory_uri() . '/assets/js/script.js', array('jquery'), $themaga_version, true);

			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}


		}
		/**
		 * Enqueue child theme stylesheet.
		 * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
		 *
		 * @since  1.0
		 * @return void
		 */
		public function child_scripts() {
			if ( is_child_theme() ) {
				wp_enqueue_style( 'themaga-child-style', get_stylesheet_uri(), '' );
			}
		}

		/**
		 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
		 *
		 * @param array $args Configuration arguments.
		 * @since  1.0
		 * @return array
		 */
		public function page_menu_args( $args ) {
			$args['show_home'] = true;
			return $args;
		}


		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @since  1.0
		 * @return array
		 */
		public function body_classes( $classes ) {
			// Adds a class of group-blog to blogs with more than 1 published author.
			if ( is_multi_author() ) {
				$classes[] = 'group-blog';
			}

			// If our main sidebar doesn't contain widgets, adjust the layout to be full-width.
			if ( ! is_active_sidebar( 'sidebar-1' ) ) {

				$classes[] = 'themaga-full-width-content';

			}

			if ( is_page_template('template-homepage.php') ) {

				$classes[] = 'homeFull';
			}

			$layout = themaga_get_theme_option( 'layout_post', 'right' );

			// Switch Sidebar Layout to left
			if ( 'left' == $layout ) {
				$classes[] = 'sidebar-left';
			}

			// Switch Sidebar Layout to No Sidebar
			if ( 'no-sidebar' == $layout ) {
				$classes[] = 'no-sidebar-post';
			}


			return $classes;
		}

	}

endif;

return new Themaga();
